# QualityCurve

Dimensionality reduction ( DR ) is a data transformation process which provides a low-dimensional ( attribute or variable ) representation of high dimensional data sets. This with the following purposes: noise reduction, storage space reduction, data visualization, efficient data processing and to concentrate the important information in fewer variables than the original set. A performance visual measure in DM is topology preservation. [Quality curves RNX], proposed by Lee and Verleysen, evaluates performance generating a graphical representation of topology preservation.  Nowadays there is a tool for topology conservation evaluation of DM algorithms, developed also by Lee and Verleysen (2009) but this tool is implemented only in Matlab. Here a problem arises because Matlab is limited and cannot be implemented in other technologies. here, we are going to implement, in python, a software evaluation module of curves RNX in order to be used in other technologies.

# New Features!
  - RNX curve and area under the curve
  - QNX curve and area under the curve
  - BNX curve and area under the curve
### Development
- Grahp for the corranking matrix
- LCMC from a coranking matrix (local continuity meta criterion)
- Error Handling

Want to contribute? Great!

License
----

MIT

**Free Software, Hell Yeah!**

[Quality curves RNX]: <https://www.sciencedirect.com/science/article/abs/pii/S0925231213001471?via%3Dihub>
